==> haskell-feed-1.0.0.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 1.0.0.0
id: feed-1.0.0.0-6gvZwCjT2hm8xNMOkK48hG
key: feed-1.0.0.0-6gvZwCjT2hm8xNMOkK48hG
license: BSD3
maintainer: Adam Bergmark <adam@bergmark.nl>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
author: Sigbjorn Finne <sof@forkIO.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils
hidden-modules: Data.Text.Util Data.XML.Compat
abi: 893c1acb626f601caed50b80ddda557a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/feed-1.0.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/feed-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-feed
hs-libraries: HSfeed-1.0.0.0-6gvZwCjT2hm8xNMOkK48hG
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    xml-types-0.3.6-JMA6F2EZctJ1CgZnvNtSRm
    xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=ac46b6403607906d7452b6c09d665690
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=8abc34d96a58625e2975ccc02aacab97
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=68a36e33bd2b1b969b7f48a0dec887aa
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=368aa3ad25486678b8f3fef19ec4be32
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=1aab9551474f1298c1817f0c2788332b
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=86282a526305f57509e4009ab924a497
             xml-types-0.3.6-JMA6F2EZctJ1CgZnvNtSRm=13ee05973782ce2b2381eaa5652bab04
             xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG=5d41ee7a789b6c188c37e2f669d70bc2
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-feed-1.0.0.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 1.0.0.0
id: feed-1.0.0.0-CeoLFZdX9ClHyo97fKtgDR
key: feed-1.0.0.0-CeoLFZdX9ClHyo97fKtgDR
license: BSD3
maintainer: Adam Bergmark <adam@bergmark.nl>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
author: Sigbjorn Finne <sof@forkIO.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils
hidden-modules: Data.Text.Util Data.XML.Compat
abi: facbc2db88f2934cdca430282f6ce615
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/feed-1.0.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/feed-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-feed
hs-libraries: HSfeed-1.0.0.0-CeoLFZdX9ClHyo97fKtgDR
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    xml-types-0.3.6-JMA6F2EZctJ1CgZnvNtSRm
    xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=ac46b6403607906d7452b6c09d665690
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=8abc34d96a58625e2975ccc02aacab97
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=68a36e33bd2b1b969b7f48a0dec887aa
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=368aa3ad25486678b8f3fef19ec4be32
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=1aab9551474f1298c1817f0c2788332b
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=86282a526305f57509e4009ab924a497
             xml-types-0.3.6-JMA6F2EZctJ1CgZnvNtSRm=13ee05973782ce2b2381eaa5652bab04
             xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm=125ff9416fb937bd7688a591a3062e03
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
